# Highlight.js CDN assets

![npm](https://badgen.net/npm/v/highlight.js)
![beta](https://badgen.net/npm/v/highlight.js/beta)
[![license](https://badgen.net/github/license/highlightjs/highlight.js?color=cyan)](https://github.com/highlightjs/highlight.js/blob/master/LICENSE)

This is the repository for the CDN release of Highlight.js that can be found on
[cdnjs][1], [jsDelivr][2], and [unpkg][3]. If you were looking for the main
repository, it is [located here][4]. If you simply need a pre-build copy of
our CDN assets, this is the repository you are looking for. All the files are in the `build` directory and you can copy over that directory to where
ever you need it.

### Fetching via NPM

This repository is also published to NPM as [@highlightjs/cdn-assets](https://www.npmjs.com/package/@highlightjs/cdn-assets).

### A note on the Git branches here

Note: The `master` branch here includes beta releases.  If you're looking for
the latest stable release code you want either one of the `stable` branches:

- [10-stable][10-stable] - The latest supported and maintained releases.
- [9-stable][9-stable] - The prior major version.  ([you probably do not want this](https://github.com/highlightjs/highlight.js/blob/master/SECURITY.md))

[1]: https://cdnjs.com/libraries/highlight.js
[2]: http://www.jsdelivr.com/#!highlight.js
[3]: https://unpkg.com/browse/@highlightjs/cdn-assets/
[4]: https://github.com/isagalaev/highlight.js
[10-stable]: https://github.com/highlightjs/cdn-release/tree/10-stable
[9-stable]: https://github.com/highlightjs/cdn-release/tree/9-stable